****
Apps
****

As we've seen in every example so far, app classes don't need to inherit from 
anything.  However, BYOC provides an `App` superclass to make two things 
easier:

- Using apps as entry points, e.g. for setuptools ``console_scripts``.

- main, entry_point
- __bare__

